@@ -43,9 +43,13 @@ TEST(mathMixScalFun, fallingFactorial_matvar) {
     return falling_factorial(x1, x2);
   };
 
+  std::vector<int> std_in2{3, 1};
   Eigen::VectorXd in1(2);
   in1 << 0.5, 3.4;
-  std::vector<int> std_in2{3, 1};
+  Eigen::MatrixXd mat(2, 2);
+  mat << 0.5, 3.4, 0.5, 3.4;
+
   stan::test::expect_ad_matvar(f, in1, std_in2);
   stan::test::expect_ad_matvar(f, in1, std_in2[0]);
+  stan::test::expect_ad_vectorized_matvar(f, mat, std_in2);
 }
